==> libreoffice-7.4.3.2.tar.xz: libreoffice-7.4.3.2/lotuswordpro/source/filter/lwplnopts.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include <lwpglobalmgr.hxx>
#include "lwplnopts.hxx"

LwpLineNumberOptions::LwpLineNumberOptions(LwpObjectStream* pStrm) { Read(pStrm); }
/**
 * @descr       Read LwpLineNumberOptions from object stream
 */
void LwpLineNumberOptions::Read(LwpObjectStream* pStrm)
{
    m_nType = pStrm->QuickReaduInt16();
    m_nFlags = pStrm->QuickReaduInt16();
    m_nSeparator = pStrm->QuickReaduInt16();
    m_nSpacing = pStrm->QuickReaduInt32();
    m_nDistance = pStrm->QuickReaduInt32();
    pStrm->SkipExtra();
}
/**
 * @descr       set XFLineNumberConfig
 */
void LwpLineNumberOptions::RegisterStyle()
{
    if (m_nType == NUMBER_NONE)
        return;
    XFLineNumberConfig* pLineNumber = new XFLineNumberConfig;
    pLineNumber->SetNumberPosition(enumXFLineNumberLeft);
    pLineNumber->SetNumberOffset(LwpTools::ConvertFromUnitsToMetric(m_nDistance));
    pLineNumber->SetNumberIncrement(m_nSeparator);
    if (m_nFlags & LN_RESETEACHPAGE)
        pLineNumber->SetRestartOnPage();
    else
        pLineNumber->SetRestartOnPage(false);
    if (m_nFlags & LN_COUNTBLANKLINES)
        pLineNumber->SetCountEmptyLines();
    else
        pLineNumber->SetCountEmptyLines(false);

    XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
    pXFStyleManager->SetLineNumberConfig(pLineNumber);
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.8.2~rc2.orig.tar.xz: libreoffice-25.8.2.2/lotuswordpro/source/filter/lwplnopts.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include <lwpglobalmgr.hxx>
#include "lwplnopts.hxx"

LwpLineNumberOptions::LwpLineNumberOptions(LwpObjectStream* pStrm) { Read(pStrm); }
/**
 * @descr       Read LwpLineNumberOptions from object stream
 */
void LwpLineNumberOptions::Read(LwpObjectStream* pStrm)
{
    m_nType = pStrm->QuickReaduInt16();
    m_nFlags = pStrm->QuickReaduInt16();
    m_nSeparator = pStrm->QuickReaduInt16();
    m_nSpacing = pStrm->QuickReaduInt32();
    m_nDistance = pStrm->QuickReaduInt32();
    pStrm->SkipExtra();
}
/**
 * @descr       set XFLineNumberConfig
 */
void LwpLineNumberOptions::RegisterStyle()
{
    if (m_nType == NUMBER_NONE)
        return;
    XFLineNumberConfig* pLineNumber = new XFLineNumberConfig;
    pLineNumber->SetNumberPosition(enumXFLineNumberLeft);
    pLineNumber->SetNumberOffset(LwpTools::ConvertFromUnits(m_nDistance));
    pLineNumber->SetNumberIncrement(m_nSeparator);
    if (m_nFlags & LN_RESETEACHPAGE)
        pLineNumber->SetRestartOnPage();
    else
        pLineNumber->SetRestartOnPage(false);
    if (m_nFlags & LN_COUNTBLANKLINES)
        pLineNumber->SetCountEmptyLines();
    else
        pLineNumber->SetCountEmptyLines(false);

    XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
    pXFStyleManager->SetLineNumberConfig(pLineNumber);
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
